summaryrefslogtreecommitdiffstats
path: root/khtml/xml
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/xml')
-rw-r--r--khtml/xml/dom2_eventsimpl.cpp28
-rw-r--r--khtml/xml/dom_docimpl.cpp4
-rw-r--r--khtml/xml/dom_docimpl.h2
-rw-r--r--khtml/xml/dom_elementimpl.cpp4
-rw-r--r--khtml/xml/dom_nodeimpl.cpp6
-rw-r--r--khtml/xml/dom_stringimpl.cpp12
-rw-r--r--khtml/xml/dom_stringimpl.h2
-rw-r--r--khtml/xml/xml_tokenizer.cpp14
-rw-r--r--khtml/xml/xml_tokenizer.h2
9 files changed, 37 insertions, 37 deletions
diff --git a/khtml/xml/dom_docimpl.cpp b/khtml/xml/dom_docimpl.cpp
index 0f70610ef..922714a4e 100644
--- a/khtml/xml/dom_docimpl.cpp
+++ b/khtml/xml/dom_docimpl.cpp
@@ -337,7 +337,7 @@ DocumentImpl::DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v)
m_namespaceMap = new IdNameMapping(1);
TQString xhtml(XHTML_NAMESPACE);
m_namespaceMap->names.insert(emptyNamespace, new DOMStringImpl(""));
- m_namespaceMap->names.insert(xhtmlNamespace, new DOMStringImpl(xhtml.tqunicode(), xhtml.length()));
+ m_namespaceMap->names.insert(xhtmlNamespace, new DOMStringImpl(xhtml.unicode(), xhtml.length()));
m_namespaceMap->names[emptyNamespace]->ref();
m_namespaceMap->names[xhtmlNamespace]->ref();
m_namespaceMap->count+=2;
@@ -1387,7 +1387,7 @@ void DocumentImpl::write( const TQString &text )
if (m_view)
m_view->part()->resetFromScript();
m_tokenizer->setAutoClose();
- write(TQString::tqfromLatin1("<html>"));
+ write(TQString::fromLatin1("<html>"));
}
m_tokenizer->write(text, false);
}
diff --git a/khtml/xml/dom_docimpl.h b/khtml/xml/dom_docimpl.h
index 8d20f47e6..5e50c09a4 100644
--- a/khtml/xml/dom_docimpl.h
+++ b/khtml/xml/dom_docimpl.h
@@ -198,7 +198,7 @@ public:
DocumentFragmentImpl *createDocumentFragment ();
TextImpl *createTextNode ( DOMStringImpl* data ) { return new TextImpl( docPtr(), data); }
TextImpl *createTextNode ( const TQString& data )
- { return createTextNode(new DOMStringImpl(data.tqunicode(), data.length())); }
+ { return createTextNode(new DOMStringImpl(data.unicode(), data.length())); }
CommentImpl *createComment ( DOMStringImpl* data );
CDATASectionImpl *createCDATASection ( DOMStringImpl* data );
ProcessingInstructionImpl *createProcessingInstruction ( const DOMString &target, DOMStringImpl* data );
diff --git a/khtml/xml/dom_elementimpl.cpp b/khtml/xml/dom_elementimpl.cpp
index f4506c8ba..552ac208e 100644
--- a/khtml/xml/dom_elementimpl.cpp
+++ b/khtml/xml/dom_elementimpl.cpp
@@ -46,7 +46,7 @@
#include "css/cssproperties.h"
#include "xml/dom_xmlimpl.h"
-#include <tqtextstream.h>
+#include <textstream.h>
#include <kdebug.h>
#include <stdlib.h>
@@ -855,7 +855,7 @@ DOMString ElementImpl::toString() const
for (NodeImpl *child = firstChild(); child != NULL; child = child->nextSibling()) {
DOMString kid = child->toString();
- result += TQConstString(kid.tqunicode(), kid.length()).string();
+ result += TQConstString(kid.unicode(), kid.length()).string();
}
result += "</";
diff --git a/khtml/xml/dom_nodeimpl.cpp b/khtml/xml/dom_nodeimpl.cpp
index 834f4b674..5febe695e 100644
--- a/khtml/xml/dom_nodeimpl.cpp
+++ b/khtml/xml/dom_nodeimpl.cpp
@@ -588,7 +588,7 @@ void NodeImpl::handleLocalEvents(EventImpl *evt, bool useCapture)
Event ev = evt;
// removeEventListener (e.g. called from a JS event listener) might
- // tqinvalidate the item after the current iterator (which "it" is pointing to).
+ // invalidate the item after the current iterator (which "it" is pointing to).
// So we make a copy of the list.
TQValueList<RegisteredEventListener> listeners = *m_regdListeners.listeners;
TQValueList<RegisteredEventListener>::iterator it;
@@ -989,7 +989,7 @@ DOMStringImpl* NodeImpl::textContent() const
delete kidText;
}
}
- return new DOMStringImpl(out.tqunicode(), out.length());
+ return new DOMStringImpl(out.unicode(), out.length());
}
//-------------------------------------------------------------------------
@@ -1925,7 +1925,7 @@ NodeImpl *GenericRONamedNodeMapImpl::item ( unsigned long index ) const
if (index >= m_contents->count())
return 0;
- return m_contents->tqat(index);
+ return m_contents->at(index);
}
unsigned long GenericRONamedNodeMapImpl::length( ) const
diff --git a/khtml/xml/dom_stringimpl.cpp b/khtml/xml/dom_stringimpl.cpp
index 14aa4f5ea..79bddf5d9 100644
--- a/khtml/xml/dom_stringimpl.cpp
+++ b/khtml/xml/dom_stringimpl.cpp
@@ -61,8 +61,8 @@ bool DOMStringImpl::containsOnlyWhitespace() const
for (uint i = 0; i < l; i++) {
TQChar c = s[i];
- if (c.tqunicode() <= 0x7F) {
- if (c.tqunicode() > ' ')
+ if (c.unicode() <= 0x7F) {
+ if (c.unicode() > ' ')
return false;
} else {
if (c.direction() != TQChar::DirWS)
@@ -294,10 +294,10 @@ khtml::Length* DOMStringImpl::toCoordsArray(int& len) const
int pos2;
while((pos2 = str.find(' ', pos)) != -1) {
- r[i++] = parseLength((TQChar *) str.tqunicode()+pos, pos2-pos);
+ r[i++] = parseLength((TQChar *) str.unicode()+pos, pos2-pos);
pos = pos2+1;
}
- r[i] = parseLength((TQChar *) str.tqunicode()+pos, str.length()-pos);
+ r[i] = parseLength((TQChar *) str.unicode()+pos, str.length()-pos);
return r;
}
@@ -320,13 +320,13 @@ khtml::Length* DOMStringImpl::toLengthArray(int& len) const
int pos2;
while((pos2 = str.find(',', pos)) != -1) {
- r[i++] = parseLength((TQChar *) str.tqunicode()+pos, pos2-pos);
+ r[i++] = parseLength((TQChar *) str.unicode()+pos, pos2-pos);
pos = pos2+1;
}
/* IE Quirk: If the last comma is the last char skip it and reduce len by one */
if (str.length()-pos > 0)
- r[i] = parseLength((TQChar *) str.tqunicode()+pos, str.length()-pos);
+ r[i] = parseLength((TQChar *) str.unicode()+pos, str.length()-pos);
else
len--;
diff --git a/khtml/xml/dom_stringimpl.h b/khtml/xml/dom_stringimpl.h
index edac46755..cd7128967 100644
--- a/khtml/xml/dom_stringimpl.h
+++ b/khtml/xml/dom_stringimpl.h
@@ -92,7 +92,7 @@ public:
DOMStringImpl *capitalize(bool noFirstCap=false) const;
DOMStringImpl *escapeHTML();
- TQChar *tqunicode() const { return s; }
+ TQChar *unicode() const { return s; }
uint length() const { return l; }
TQString string() const;
diff --git a/khtml/xml/xml_tokenizer.cpp b/khtml/xml/xml_tokenizer.cpp
index 8f6164f51..7c043815a 100644
--- a/khtml/xml/xml_tokenizer.cpp
+++ b/khtml/xml/xml_tokenizer.cpp
@@ -42,7 +42,7 @@ using namespace DOM;
using namespace khtml;
XMLIncrementalSource::XMLIncrementalSource()
- : TQXmlInputSource(), m_pos( 0 ), m_tqunicode( 0 ),
+ : TQXmlInputSource(), m_pos( 0 ), m_unicode( 0 ),
m_finished( false )
{
}
@@ -59,13 +59,13 @@ TQChar XMLIncrementalSource::next()
else if ( m_data.length() <= m_pos )
return TQXmlInputSource::EndOfData;
else
- return m_tqunicode[m_pos++];
+ return m_unicode[m_pos++];
}
void XMLIncrementalSource::setData( const TQString& str )
{
m_data = str;
- m_tqunicode = m_data.tqunicode();
+ m_unicode = m_data.unicode();
m_pos = 0;
if ( !str.isEmpty() )
m_finished = false;
@@ -78,7 +78,7 @@ void XMLIncrementalSource::setData( const TQByteArray& data )
void XMLIncrementalSource::appendXML( const TQString& str )
{
m_data += str;
- m_tqunicode = m_data.tqunicode();
+ m_unicode = m_data.unicode();
}
TQString XMLIncrementalSource::data()
@@ -289,7 +289,7 @@ bool XMLHandler::comment(const TQString & ch)
if (currentNode()->nodeType() == Node::TEXT_NODE)
exitText();
// ### handle exceptions
- currentNode()->addChild(m_doc->createComment(new DOMStringImpl(ch.tqunicode(), ch.length())));
+ currentNode()->addChild(m_doc->createComment(new DOMStringImpl(ch.unicode(), ch.length())));
return true;
}
@@ -299,7 +299,7 @@ bool XMLHandler::processingInstruction(const TQString &target, const TQString &d
exitText();
// ### handle exceptions
ProcessingInstructionImpl *pi =
- m_doc->createProcessingInstruction(target, new DOMStringImpl(data.tqunicode(), data.length()));
+ m_doc->createProcessingInstruction(target, new DOMStringImpl(data.unicode(), data.length()));
currentNode()->addChild(pi);
pi->checkStyleSheet();
return true;
@@ -364,7 +364,7 @@ bool XMLHandler::internalEntityDecl(const TQString &name, const TQString &value)
{
EntityImpl *e = new EntityImpl(m_doc,name);
// ### further parse entities inside the value and add them as separate nodes (or entityreferences)?
- e->addChild(m_doc->createTextNode(new DOMStringImpl(value.tqunicode(), value.length())));
+ e->addChild(m_doc->createTextNode(new DOMStringImpl(value.unicode(), value.length())));
if (m_doc->doctype())
static_cast<GenericRONamedNodeMapImpl*>(m_doc->doctype()->entities())->addNode(e);
return true;
diff --git a/khtml/xml/xml_tokenizer.h b/khtml/xml/xml_tokenizer.h
index d2910472e..749c423ff 100644
--- a/khtml/xml/xml_tokenizer.h
+++ b/khtml/xml/xml_tokenizer.h
@@ -155,7 +155,7 @@ public:
private:
TQString m_data;
uint m_pos;
- const TQChar *m_tqunicode;
+ const TQChar *m_unicode;
bool m_finished;
};
diff --git a/khtml/xml/dom2_eventsimpl.cpp b/khtml/xml/dom2_eventsimpl.cpp
index c49a03e78..5121e9caf 100644
--- a/khtml/xml/dom2_eventsimpl.cpp
+++ b/khtml/xml/dom2_eventsimpl.cpp
@@ -48,7 +48,7 @@ EventImpl::EventImpl()
m_currentTarget = 0;
m_eventPhase = 0;
m_target = 0;
- m_createTime = TQDateTime::tqcurrentDateTime();
+ m_createTime = TQDateTime::currentDateTime();
m_defaultHandled = false;
}
@@ -67,7 +67,7 @@ EventImpl::EventImpl(EventId _id, bool canBubbleArg, bool cancelableArg)
m_currentTarget = 0;
m_eventPhase = 0;
m_target = 0;
- m_createTime = TQDateTime::tqcurrentDateTime();
+ m_createTime = TQDateTime::currentDateTime();
m_defaultHandled = false;
}
@@ -590,10 +590,10 @@ KeyEventBaseImpl::KeyEventBaseImpl(EventId id, bool canBubbleArg, bool cancelabl
m_keyVal = key->ascii();
m_virtKeyVal = virtKeyToQtKey()->toLeft(key->key());
// m_keyVal should contain the tqunicode value
// of the pressed key if available.
if (m_virtKeyVal == DOM_VK_UNDEFINED && !key->text().isEmpty())
- m_keyVal = TQString(key->text()).tqunicode()[0];
+ m_keyVal = TQString(key->text()).unicode()[0];
// key->state returns enum ButtonState, which is ShiftButton, ControlButton and AltButton or'ed together.
m_modifier = key->state();
@@ -739,10 +739,10 @@ DOMString KeyboardEventImpl::keyIdentifier() const
{
if (unsigned special = virtKeyVal())
if (const char* id = keyIdentifiersToVirtKeys()->toLeft(special))
- return TQString::tqfromLatin1(id);
+ return TQString::fromLatin1(id);
- if (unsigned tqunicode = keyVal())
- return TQString(TQChar(tqunicode));
+ if (unsigned unicode = keyVal())
+ return TQString(TQChar(unicode));
return "Unidentified";
}
@@ -773,9 +773,9 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
//Figure out the code information from the key identifier.
if (keyIdentifierArg.length() == 1) {
//Likely to be normal tqunicode id, unless it's one of the few
//special values.
- unsigned short code = keyIdentifierArg.tqunicode()[0];
+ unsigned short code = keyIdentifierArg.unicode()[0];
if (code > 0x20 && code != 0x7F)
keyVal = code;
}
@@ -819,7 +819,7 @@ int KeyboardEventImpl::keyCode() const
if (m_virtKeyVal != DOM_VK_UNDEFINED)
return m_virtKeyVal;
else
- return TQChar((unsigned short)m_keyVal).upper().tqunicode();
+ return TQChar((unsigned short)m_keyVal).upper().unicode();
}
int KeyboardEventImpl::charCode() const
@@ -856,14 +856,14 @@ void TextEventImpl::initTextEvent(const DOMString &typeArg,
//See whether we can get a key out of this.
unsigned keyCode = 0;
if (text.length() == 1)
- keyCode = text.tqunicode()[0].tqunicode();
+ keyCode = text.unicode()[0].unicode();
initKeyBaseEvent(typeArg, canBubbleArg, cancelableArg, viewArg,
keyCode, 0, 0);
}
int TextEventImpl::keyCode() const
{
//Mozilla returns 0 here unless this is a non-tqunicode key.
//IE stuffs everything here, and so we try to match it..
if (m_keyVal)
return m_keyVal;
@@ -872,8 +872,8 @@ int TextEventImpl::keyCode() const
int TextEventImpl::charCode() const
{
//On text events, in Mozilla charCode is 0 for non-tqunicode keys,
//and the tqunicode key otherwise... IE doesn't support this.
if (m_virtKeyVal)
return 0;
return m_keyVal;
@@ -590,10 +590,10 @@ KeyEventBaseImpl::KeyEventBaseImpl(EventId id, bool canBubbleArg, bool cancelabl
m_keyVal = key->ascii();
m_virtKeyVal = virtKeyToQtKey()->toLeft(key->key());
- // m_keyVal should contain the tqunicode value
+ // m_keyVal should contain the unicode value
// of the pressed key if available.
if (m_virtKeyVal == DOM_VK_UNDEFINED && !key->text().isEmpty())
@@ -773,9 +773,9 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
//Figure out the code information from the key identifier.
if (keyIdentifierArg.length() == 1) {
- //Likely to be normal tqunicode id, unless it's one of the few
+ //Likely to be normal unicode id, unless it's one of the few
//special values.
@@ -856,14 +856,14 @@ void TextEventImpl::initTextEvent(const DOMString &typeArg,
int TextEventImpl::keyCode() const
{
- //Mozilla returns 0 here unless this is a non-tqunicode key.
+ //Mozilla returns 0 here unless this is a non-unicode key.
//IE stuffs everything here, and so we try to match it..
if (m_keyVal)
@@ -872,8 +872,8 @@ int TextEventImpl::keyCode() const
int TextEventImpl::charCode() const
{
- //On text events, in Mozilla charCode is 0 for non-tqunicode keys,
- //and the tqunicode key otherwise... IE doesn't support this.
+ //On text events, in Mozilla charCode is 0 for non-unicode keys,
+ //and the unicode key otherwise... IE doesn't support this.
if (m_virtKeyVal)
return 0;